First time set up of AMIRIS? Got questions? Here you go! 

# Install AMIRIS
To get AMIRIS running, please follow the install instructions in the [ReadMe](https://gitlab.com/dlr-ve/esy/amiris/amiris/-/blob/main/README.md)

# Use FAME-Io
AMIRIS is based on [FAME](https://gitlab.com/fame-framework/).
Therefore, AMIRIS input files need to be written to a `protobuf` binary file first.
Also, all results from AMIRIS will be in a protobuf binary format.
To translate between human-readable inputs / outputs and protobuf binary files, [FAME-Io](https://gitlab.com/fame-framework/fame-io) is used.

## Set up Python Environment
You need to setup an environment with Python 3.7 or higher + pip + [FAME-Io](https://gitlab.com/fame-framework/fame-io).
We provide instructions for environment creation with [anaconda ](https://www.anaconda.com/) prompt:

1. `conda create -n fameEnv python=3.7`
2. `conda activate fameEnv`
3. `pip install fameio`

FAME-Io comes with two scripts
* `makeFameRunConfig` translates configuration files to binary AMIRIS input in `protobuf` format
* `convertFameResults ` extracts AMIRIS results in `protobuf` format to human-readable .csv files

## Create Binary Input
Creating a full-blow scenario for an energy market can take quite some time.
Luckily, we have example scenarios prepared for you.
Clone the files of the AMIRIS [examples](https://gitlab.com/dlr-ve/esy/amiris/examples) parametrisation project into the "input/"-directory of your AMIRIS project.

1. change to the input directory and choose one example project folder
2. load the python environment with `fameio` 
3. execute `makeFameRunConfig -f yaml/scenario.yaml`

This should then generate a protobuf config file called `config.pb` in the current folder, i.e. 

/.../amiris/input/config.pb

If this is not the case, please note the path to your "config.pb" and enter it after the "-f " when calling AMIRIS.
You may also have a look at the actual parametrisation in the provided YAML files or TimeSeries data.

## Extracting Results
Once you've run AMIRIS you obtained binary output file(s).
To be able to read them, you may use FAME-Io to extract the result data in .CSV form.

1. change to the output directory
2. load the `fameio` python environment 
3. execute: `convertFameResults -f AMIRIS_<XYZ>.pb`

where "AMIRIS_<XYZ>" is the name of your output file.
This will create a folder with the name of the binary file.
In this folder a .CSV file for each type of agent will be created with the following structure:

|agentId|TimeStep|Col1|Col2|Col3|...|
|-------|--------|----|----|----|---|

where:
* `agentId` refers to the unique ID of that agent - as specified in input/yaml/scenario.yaml 
* `TimeStep` refers to the time step at which the output was created; the number refers to the passed seconds since January 1st 2000, 00:00h (ignoring leap years). To convert to a human-readable time stamp best use the python function `fameio.source.time.FameTime.convert_fame_time_step_to_datetime`
* `Col1` refers to the agent-type specific first output column
* `Col2` refers to the agent-type specific second output column
* `...` there can be arbitrarily many output columns - depending on the type of the agent 

Best you open the files in your favourite .CSV editor.
You can check the market-clearing day-ahead electricity prices at the "EnergyExchange" agent's second data column name "ElectricityPriceInEURperMWH".
Don't worry that the different agents do not all write out at the exact same time step - this is normal.
Some actions are done before market clearing, others are done afterwards - and the output is usually created at the time when the action is performed. 

## AMIRIS execution: explained
To start AMIRIS on the console, the following command is used:

```
    java -cp "target/amiris-jar-with-dependencies.jar" de.dlr.gitlab.fame.setup.FameRunner -f input/config.pb
```
Its components are:
1. `java` fires up the installed java runtime environment -- if this does not happen, please ensure you have your java-command pointing to a JDK version 1.8 or higher.
2. `-cp "target/amiris-jar-with-dependencies.jar"` tells Java to load the built amiris project into the "classpath" - thus the functions from that file are now available
3. `de.dlr.gitlab.fame.setup.FameRunner` tells Java to start the execution at the given classes "main" function. For AMIRIS, the main executable is from FAME.
4. `-f input/config.pb` tells the FameRunner to load the given config file and read its simulation setup. Since this setup explicitly refers to AMIRIS classes, FAME will load these classes and feed them with the input data provided in the config file. 

Running AMIRIS creates result files in the "result" folder named "AMIRIS_XYZ.pb".
Here, "XYZ" is a time stamp indicating the system time when the simulation was started.
You can change the name of the output file, its path and decide whether you want a time stamp attached or not by editing the file "fameSetup.yaml" in the AMIRIS root directory.